@@ -7,7 +7,7 @@ def update():
     """
     updates a virtualenv (pip install requirements.txt)
     """
-    do_run('cd %(path)s; bin/pip install -r requirements.txt --upgrade' % config.sites["main"].deployment)
+    do_run('cd %(path)s; bin/pip install -r requirements.txt --upgrade --no-deps' % config.sites["main"].deployment)
 
 @task
 def create():
